CREATE OR REPLACE PROCEDURE ARQUIVO_DOT(
   P_CDIMPOSTO    IN IMPOSTO.CDIMPOSTO%TYPE,
   P_CDEMPRESA    IN EMPRESA.CDEMPRESA%TYPE,
   P_CDINSCESTA   IN EMPRESA.CDINSCESTA%TYPE,
   P_CDLIVROMAG   IN LIVROMAGNETICO.CDLIVROMAG%TYPE,
   P_DTINICIAL    IN NOTAFISCAL.DTENTRSAID%TYPE,
   P_DTFINAL      IN NOTAFISCAL.DTENTRSAID%TYPE,
   P_FORMAAPRE    IN NOTAFISCAL.CDTIPOOPER%TYPE,
   P_STCOMPRAS    IN NOTAFISCAL.CDTIPOOPER%TYPE,
   P_NRSEQARQMAG  IN ARQMAGNETICO.NRSEQARQMAG%TYPE)
AS
   V_CONT                  NUMBER;
   V_CDINSCESTA            VARCHAR2(15);
   V_DTINICIAL             VARCHAR2(8);
   V_DTFINAL               VARCHAR2(8);
   V_CDMUNIEXPO            VARCHAR2(5);
   V_VRESTINI              VARCHAR2(20);
   V_VRESTFIM              VARCHAR2(20);
   V_ENTR_ESTADO           VARCHAR2(20);
   V_ENTR_PRODRURAL        VARCHAR2(20);
   V_ENTR_PESSOAFISICA     VARCHAR2(20);
   V_ENTR_OUTROSESTADOS    VARCHAR2(20);
   V_ENTR_EXTERIOR         VARCHAR2(20);
   V_SAID_ESTADO           VARCHAR2(20);
   V_SAID_OUTROSESTADOS    VARCHAR2(20);
   V_SAID_EXTERIOR         VARCHAR2(20);
   V_ENERGIA_ELETRICA      VARCHAR2(20);
   V_TRANSPORTE            VARCHAR2(20);
   V_COMUNICACAO           VARCHAR2(20);
   V_PETROLEO              VARCHAR2(20);
   V_AGUA                  VARCHAR2(20);
   V_OUTRAS_ATIVIDADES     VARCHAR2(20);
   V_OUTROS                VARCHAR2(20);
   V_OBSERVACAO            VARCHAR2(20);
BEGIN
   V_CONT := 0;

   /*Tipo do arquivo xml a ser carregado*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<?xml version="1.0" encoding="ISO-8859-1"?>',P_NRSEQARQMAG);

   /*TAG de Abertura do Arquivo*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<IMPORTAR_DOTS>',P_NRSEQARQMAG);

   /*TAG de incio de declarao*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<DECLARACAO>',P_NRSEQARQMAG);

   /*DADOS INICIAIS*/
   SELECT REPLACE(LTRIM(TO_CHAR(SUBSTR(LPAD(P_CDINSCESTA,9,'0'),1,8),'000G000G00')),' ','.') || '-' ||SUBSTR(LPAD(P_CDINSCESTA,9,'0'),9,1) AS CDINCESTA,
          TO_CHAR(TO_DATE(P_DTINICIAL),'YYYYMMDD') AS DTINICIAL, TO_CHAR(TO_DATE(P_DTFINAL),'YYYYMMDD') AS DTFINAL
     INTO V_CDINSCESTA, V_DTINICIAL, V_DTFINAL
     FROM DUAL;

   /*MUNICPIO DE EXPORTAO*/
   BEGIN
      SELECT NVL(MU.CDMUNIEXPO,MU.CDMUNICIPIO)
        INTO V_CDMUNIEXPO
        FROM INSCRESTAD I, MUNICIPIO MU
       WHERE I.CDEMPRESA   = P_CDEMPRESA
         AND I.CDINSCESTA  = P_CDINSCESTA
         AND I.CDPAIS      = MU.CDPAIS
         AND I.SGESTADO    = MU.SGESTADO
         AND I.CDMUNICIPIO = MU.CDMUNICIPIO;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
           V_CDMUNIEXPO := '00000';
   END;

   /*ESTOQUE INICIAL*/
   BEGIN
      SELECT LTRIM(TO_CHAR(NVL(SUM(I.VRTOTINVFISC),0),'999999999999990.00'))
        INTO V_VRESTINI
        FROM INVENTFISC I
       WHERE I.CDEMPRESA     = P_CDEMPRESA
         AND I.CDINSCESTA    = P_CDINSCESTA
         AND I.QTESTINVFISC <> 0
         AND I.DTINVEFISCAL  = (SELECT MAX(DTINVEFISCAL)
                                  FROM INVENTFISC V
                                 WHERE V.DTINVEFISCAL <= (P_DTINICIAL - 1)
                                   AND V.CDEMPRESA     = P_CDEMPRESA
                                   AND V.CDINSCESTA    = P_CDINSCESTA
                                   AND V.QTESTINVFISC <> 0);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_VRESTINI := NULL;
   END;

   /*ESTOQUE FINAL*/
   BEGIN
      SELECT LTRIM(TO_CHAR(NVL(SUM(I.VRTOTINVFISC),0),'999999999999990.00'))
        INTO V_VRESTFIM
        FROM INVENTFISC I
       WHERE I.CDEMPRESA     = P_CDEMPRESA
         AND I.CDINSCESTA    = P_CDINSCESTA
         AND I.QTESTINVFISC <> 0
         AND I.DTINVEFISCAL  = (SELECT MAX(DTINVEFISCAL)
                                  FROM INVENTFISC V
                                 WHERE V.DTINVEFISCAL <= P_DTFINAL
                                   AND V.CDEMPRESA     = P_CDEMPRESA
                                   AND V.CDINSCESTA    = P_CDINSCESTA
                                   AND V.QTESTINVFISC <> 0);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_VRESTFIM := NULL;
   END;

   /*Valores das Entradas*/
   BEGIN
      SELECT LTRIM(TO_CHAR(NVL(SUM(DECODE(CFOP,'1', DECODE(IDTPIJURFORN,'F',0,
                  CASE WHEN ((MODELO IN ('1B','04')) OR ((MODELO = '55') AND (SERIE BETWEEN '890' AND '899')))
                       THEN 0 ELSE VRCONTABILNF END),0)),0),'999999999999990.00')) AS VRESTADO,
             LTRIM(TO_CHAR(NVL(SUM(DECODE(CFOP,'1',DECODE(MODELO,'04',VRCONTABILNF,0),0)),0),'999999999999990.00')) AS VRPRODRURAL,
             '0.00' AS VRAQZPESSOAFISICA,
             LTRIM(TO_CHAR(NVL(SUM(DECODE(CFOP,'2',VRCONTABILNF,0)),0),'999999999999990.00')) AS VROUTROSESTADOS,
             LTRIM(TO_CHAR(NVL(SUM(DECODE(CFOP,'3',VRCONTABILNF,0)),0),'999999999999990.00')) AS VREXTERIOR,
             LTRIM(TO_CHAR(NVL(SUM(VROUTROS),0),'999999999999990.00')) AS VROUTROS
        INTO V_ENTR_ESTADO, V_ENTR_PRODRURAL, V_ENTR_PESSOAFISICA, V_ENTR_OUTROSESTADOS, V_ENTR_EXTERIOR, V_OUTROS
        FROM (SELECT SUM(IP.VRCONTABILNF) AS VRCONTABILNF, SUBSTR(IP.CDFISCOPERNF,1,1) AS CFOP, NF.CDMODDOCFISC AS MODELO,
                   NF.CDSERIEENTR AS SERIE, NVL(NVL(FO.IDTPIJURFORN,CL.IDTPIJURCLIE),FI.IDTPIJURFILI) AS IDTPIJURFORN,
                   SUM(CASE WHEN CDFISCOPERNF IN ('1931','1932','2931','2932') THEN VRCONTABILNF ELSE 0 END) AS VROUTROS
              FROM MAPAAPURAC MP, IMPOSTONF IP, NOTAFISCAL NF, IMPOSTO IM, CLIENTE CL, FORNECEDOR FO, FILIAL FI, CFOPLIVROMAG CF
             WHERE MP.CDEMPRESA     = P_CDEMPRESA
               AND MP.CDIMPOSTO     = P_CDIMPOSTO
               AND MP.CDINSCESTA    = P_CDINSCESTA
               AND MP.DTINIPERIODO >= P_DTINICIAL
               AND MP.DTFIMPERIODO <= P_DTFINAL
               AND IP.NRSEQUMAPAPU  = MP.NRSEQUMAPAPU
               AND IP.CDFILIAL      = NF.CDFILIAL
               AND IP.NRLANCTONF    = NF.NRLANCTONF
               AND NF.IDENTRSAIDOP  = 'E'
               AND IP.CDIMPOSTO     = IM.CDIMPOSTO
               AND IM.CDIMPOSTONFE  = P_CDIMPOSTO
               AND NF.CDCLIENTE     = CL.CDCLIENTE(+)
               AND NF.CDFORNECED    = FO.CDFORNECED(+)
               AND NF.CDFILIEMIT    = FI.CDFILIAL(+)
               AND CF.CDLIVROMAG    = P_CDLIVROMAG
               AND CF.CDLAYOUTLMAG  = '001'
               AND ((IP.CDFISCOPERNF <> CF.CDCFOPLMAG)
                OR (IP.CDFISCOPERNF IN ('1949','2949','3949') AND IP.VRIMPOSTONF > 0))
          GROUP BY SUBSTR(IP.CDFISCOPERNF,1,1), NF.CDMODDOCFISC, NF.CDSERIEENTR, NVL(NVL(FO.IDTPIJURFORN,CL.IDTPIJURCLIE),FI.IDTPIJURFILI));
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_ENTR_ESTADO        := '0.00';
         V_ENTR_PRODRURAL     := '0.00';
         V_ENTR_PESSOAFISICA  := '0.00';
         V_ENTR_OUTROSESTADOS := '0.00';
         V_ENTR_EXTERIOR      := '0.00';
   END;

   /*Valores das Sadas*/
   BEGIN
      SELECT LTRIM(TO_CHAR(NVL(SUM(DECODE(SUBSTR(I.CDFISCOPERNF,1,1),'5',I.VRCONTABILNF,0)),0),'999999999999990.00')) AS VRSAIDA_ESTADO,
             LTRIM(TO_CHAR(NVL(SUM(DECODE(SUBSTR(I.CDFISCOPERNF,1,1),'6',I.VRCONTABILNF,0)),0),'999999999999990.00')) AS VRSAIDA_OUTROSESTADOS,
             LTRIM(TO_CHAR(NVL(SUM(DECODE(SUBSTR(I.CDFISCOPERNF,1,1),'7',I.VRCONTABILNF,0)),0),'999999999999990.00')) AS VRSAIDA_EXTERIOR
        INTO V_SAID_ESTADO, V_SAID_OUTROSESTADOS, V_SAID_EXTERIOR
        FROM MAPAAPURAC M, IMPOSTONF I, NOTAFISCAL N, IMPOSTO IM, CFOPLIVROMAG CF
       WHERE M.CDEMPRESA     = P_CDEMPRESA
         AND M.CDIMPOSTO     = P_CDIMPOSTO
         AND M.CDINSCESTA    = P_CDINSCESTA
         AND M.DTINIPERIODO >= P_DTINICIAL
         AND M.DTFIMPERIODO <= P_DTFINAL
         AND I.NRSEQUMAPAPU  = M.NRSEQUMAPAPU
         AND I.CDFILIAL      = N.CDFILIAL
         AND I.NRLANCTONF    = N.NRLANCTONF
         AND N.IDENTRSAIDOP  = 'S'
         AND I.CDIMPOSTO     = IM.CDIMPOSTO
         AND IM.CDIMPOSTONFE = P_CDIMPOSTO
         AND CF.CDLIVROMAG    = P_CDLIVROMAG
         AND CF.CDLAYOUTLMAG  = '003'
         AND ((I.CDFISCOPERNF <> CF.CDCFOPLMAG)
          OR (CDFISCOPERNF IN ('5949','6949','7210','7949') AND I.VRIMPOSTONF > 0));
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_SAID_ESTADO        := '0.00';
         V_SAID_OUTROSESTADOS := '0.00';
         V_SAID_EXTERIOR      := '0.00';
   END;
   /*Valores Outras Atividades*/
   BEGIN
      SELECT LTRIM(TO_CHAR(NVL(SUM(VRCONTABILNF),0),'999999999999990.00'))
        INTO V_OUTRAS_ATIVIDADES
        FROM MAPAAPURAC M, IMPOSTONF I, NOTAFISCAL N, IMPOSTO IM, CFOPLIVROMAG CF
       WHERE M.CDEMPRESA     = P_CDEMPRESA
         AND M.CDIMPOSTO     = P_CDIMPOSTO
         AND M.CDINSCESTA    = P_CDINSCESTA
         AND M.DTINIPERIODO >= P_DTINICIAL
         AND M.DTFIMPERIODO <= P_DTFINAL
         AND I.NRSEQUMAPAPU  = M.NRSEQUMAPAPU
         AND I.CDFILIAL      = N.CDFILIAL
         AND I.NRLANCTONF    = N.NRLANCTONF
         AND CF.CDLIVROMAG   = P_CDLIVROMAG
         AND CF.CDLAYOUTLMAG = '002'
         AND I.CDFISCOPERNF  = CF.CDCFOPLMAG
         AND N.IDENTRSAIDOP  = 'S'
         AND I.CDIMPOSTO     = IM.CDIMPOSTO
         AND IM.CDIMPOSTONFE = P_CDIMPOSTO;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_OUTRAS_ATIVIDADES := '0.00';
   END;
   V_ENERGIA_ELETRICA  := '0.00';
   V_TRANSPORTE        := '0.00';
   V_COMUNICACAO       := '0.00';
   V_PETROLEO          := '0.00';
   V_AGUA              := '0.00';

   /*Inscrio Estadual*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<NUM_INSCEST>'||V_CDINSCESTA||'</NUM_INSCEST>',P_NRSEQARQMAG);

   /*Data Inicial*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<DATA_INICIO_DECLARACAO>'||V_DTINICIAL||'</DATA_INICIO_DECLARACAO>',P_NRSEQARQMAG);

   /*Data Final*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<DATA_FIM_DECLARACAO>'||V_DTFINAL||'</DATA_FIM_DECLARACAO>',P_NRSEQARQMAG);

   /*Cdigo do Municpio de Exportao*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<CODG_MUNICIPIO>'||V_CDMUNIEXPO||'</CODG_MUNICIPIO>',P_NRSEQARQMAG);

   /*Cdigo de Apresentao*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<CODG_APRESENTACAO>'||P_FORMAAPRE||'</CODG_APRESENTACAO>',P_NRSEQARQMAG);

   /*Estoque Inicial*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_ESTOQUE_INICIAL>'||V_VRESTINI||'</VALR_ESTOQUE_INICIAL>',P_NRSEQARQMAG);

   /*Compras, transferncias e devolues do Estado*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_COMPRA_DEVOL_TRANSF>'||V_ENTR_ESTADO||'</VALR_COMPRA_DEVOL_TRANSF>',P_NRSEQARQMAG);

   /*Entrada de produo rural prpria.*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_PROD_RURAL_PROPRIA>'||V_ENTR_PRODRURAL||'</VALR_PROD_RURAL_PROPRIA>',P_NRSEQARQMAG);

   /*Compras pessoa fsica ou no contribuinte do ICMS no Estado.*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_AQZ_PESSOA_FISICA>'||V_ENTR_PESSOAFISICA||'</VALR_AQZ_PESSOA_FISICA>',P_NRSEQARQMAG);

   /*Compras, transferncias e devolues de outros estados.*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_COMPRA_FORA_EST>'||V_ENTR_OUTROSESTADOS||'</VALR_COMPRA_FORA_EST>',P_NRSEQARQMAG);

   /*Compras, transferncias e devolues do exterior.*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_COMPRA_EXTERIOR>'||V_ENTR_EXTERIOR||'</VALR_COMPRA_EXTERIOR>',P_NRSEQARQMAG);

   /*Vendas, transferncias e devolues internas*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_VENDA_DEVOLUCAO>'||V_SAID_ESTADO||'</VALR_VENDA_DEVOLUCAO>',P_NRSEQARQMAG);

   /*Vendas, transferncias, e devolues para outros estados*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_VENDA_FORA_ESTADO>'||V_SAID_OUTROSESTADOS||'</VALR_VENDA_FORA_ESTADO>',P_NRSEQARQMAG);

   /*Vendas para o exterior*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_VENDA_EXTERIOR>'||V_SAID_EXTERIOR||'</VALR_VENDA_EXTERIOR>',P_NRSEQARQMAG);

   /*Estoque Final*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_ESTOQUE_FINAL>'||V_VRESTFIM||'</VALR_ESTOQUE_FINAL>',P_NRSEQARQMAG);

   /*Energia Eltrica*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_ENERGIA_ELETRICA>'||V_ENERGIA_ELETRICA||'</VALR_ENERGIA_ELETRICA>',P_NRSEQARQMAG);

   /*Transporte*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_TRANSPORTE>'||V_TRANSPORTE||'</VALR_TRANSPORTE>',P_NRSEQARQMAG);

   /*Comunicao*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_COMUNICACAO>'||V_COMUNICACAO||'</VALR_COMUNICACAO>',P_NRSEQARQMAG);

   /*Extrao de petrleo*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_EXTRACAO_PETROLEO>'||V_PETROLEO||'</VALR_EXTRACAO_PETROLEO>',P_NRSEQARQMAG);

   /*Distribuio de gua Canalizada*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_AGUA>'||V_AGUA||'</VALR_AGUA>',P_NRSEQARQMAG);

   /*Outras Atividades*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_OUTRAS_ATIVIDADES>'||V_OUTRAS_ATIVIDADES||'</VALR_OUTRAS_ATIVIDADES>',P_NRSEQARQMAG);

   /*Outros*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<VALR_OUTROS_SER_TRANS>'||V_OUTROS||'</VALR_OUTROS_SER_TRANS>',P_NRSEQARQMAG);

   /*Informaes Complementares*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'<MEMO_OBS></MEMO_OBS>',P_NRSEQARQMAG);

   /*Verifica se ser necessrio gerar registros de Detalhamento*/
   IF (V_ENTR_PRODRURAL <> '0.00') OR (V_OUTRAS_ATIVIDADES <> '0.00') THEN
      V_CONT := NVL(V_CONT,0)+1;
      /*TAG que indica necessidade de gerao de Detalhamentos*/
      INSERT INTO ARQMAGNETICO
         (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
      VALUES
         (LPAD(V_CONT,10,'0'),'<DETALHAMENTOS>',P_NRSEQARQMAG);

      /* Caso haja valores de Produo Rural Prpria (Nota de Produtor Rural - Modelo 04)
      deve ser gerado o detalhamento por municpio*/
      IF V_ENTR_PRODRURAL <> '0.00' THEN
         FOR DETA_PROD IN(SELECT LTRIM(TO_CHAR(VRCONTABILNF,'999999999999990.00')) AS VRCONTABIL,
                                 NVL(MU.CDMUNIEXPO,MU.CDMUNICIPIO) AS COD_MUNI
                            FROM(SELECT NVL(SUM(IP.VRCONTABILNF),0) AS VRCONTABILNF,
                                        NVL(NVL(EF.CDMUNICIPIO,EC.CDMUNICIPIO),EL.CDMUNICIPIO) AS MUNICIPIO,
                                        NVL(NVL(EF.SGESTADO,EC.SGESTADO),EL.SGESTADO) AS SGESTADO,
                                        NVL(NVL(EF.CDPAIS,EC.CDPAIS),EL.CDPAIS) AS CDPAIS
                                   FROM MAPAAPURAC MP, IMPOSTONF IP, NOTAFISCAL NF, IMPOSTO IM, ENDEFORN EF, ENDECLIE EC, ENDEFILI EL
                                  WHERE MP.CDEMPRESA     = P_CDEMPRESA
                                    AND MP.CDIMPOSTO     = P_CDIMPOSTO
                                    AND MP.CDINSCESTA    = P_CDINSCESTA
                                    AND MP.DTINIPERIODO >= P_DTINICIAL
                                    AND MP.DTFIMPERIODO <= P_DTFINAL
                                    AND IP.NRSEQUMAPAPU  = MP.NRSEQUMAPAPU
                                    AND IP.CDFILIAL      = NF.CDFILIAL
                                    AND IP.NRLANCTONF    = NF.NRLANCTONF
                                    AND NF.IDENTRSAIDOP  = 'E'
                                    AND IP.CDIMPOSTO     = IM.CDIMPOSTO
                                    AND IM.CDIMPOSTONFE  = P_CDIMPOSTO
                                    AND NF.CDFORNECED    = EF.CDFORNECED(+)
                                    AND NF.CDCLIENTE     = EC.CDCLIENTE(+)
                                    AND NF.CDFILIEMIT    = EL.CDFILIAL(+)
                                    AND EF.IDTPENDEFORN(+)= 'P'
                                    AND EC.IDTPENDECLIE(+)= 'P'
                                    AND EL.IDTPENDEFILI(+)= 'P'
                                    AND NF.CDMODDOCFISC  = '04'
                                    AND SUBSTR(CDFISCOPERNF,1,1) = '1'
                                    AND (IP.CDFISCOPERNF NOT IN ('1128','1153','1251','1253','1254','1255','1256','1257','1301','1302','1303','1304','1305','1306',
                                                                 '1351','1354','1355','1356','1406','1407','1414','1415','1503','1504','1505','1506','1551','1552',
                                                                 '1553','1554','1555','1556','1557','1601','1603','1605','1663','1664','1904','1905','1906','1907',
                                                                 '1908','1909','1911','1912','1913','1914','1915','1916','1920','1921','1922','1923','1933','1934','1949')
                                          OR (IP.CDFISCOPERNF = '1949' AND IP.VRIMPOSTONF > 0))
                                   GROUP BY NVL(NVL(EF.CDMUNICIPIO,EC.CDMUNICIPIO),EL.CDMUNICIPIO),
                                            NVL(NVL(EF.SGESTADO,EC.SGESTADO),EL.SGESTADO),NVL(NVL(EF.CDPAIS,EC.CDPAIS),EL.CDPAIS)) A, MUNICIPIO MU
                                 WHERE MU.CDMUNICIPIO = A.MUNICIPIO
                                   AND MU.SGESTADO    = A.SGESTADO
                                   AND MU.CDPAIS      = A.CDPAIS
                                   AND MU.SGESTADO    = 'ES'
                                 UNION
                                SELECT LTRIM(TO_CHAR(SUM(CASE WHEN ((MODELO = '1B') OR ((MODELO = '55') AND (SERIE BETWEEN '890' AND '899')) OR (IDTPIJURFORN = 'F'))
                                                       THEN VRCONTABILNF ELSE 0 END),'999999999999990.00')) AS VRCONTABIL,
                                 NVL(MU.CDMUNIEXPO,MU.CDMUNICIPIO) AS COD_MUNI
                            FROM(SELECT NVL(SUM(IP.VRCONTABILNF),0) AS VRCONTABILNF,
                                        NVL(NVL(EF.CDMUNICIPIO,EC.CDMUNICIPIO),EL.CDMUNICIPIO) AS MUNICIPIO,
                                        NVL(NVL(EF.SGESTADO,EC.SGESTADO),EL.SGESTADO) AS SGESTADO,
                                        NVL(NVL(EF.CDPAIS,EC.CDPAIS),EL.CDPAIS) AS CDPAIS,
                                        NVL(NVL(FO.IDTPIJURFORN,CL.IDTPIJURCLIE),FI.IDTPIJURFILI) AS IDTPIJURFORN,
                                        NF.CDMODDOCFISC AS MODELO, NF.CDSERIEENTR AS SERIE
                                   FROM MAPAAPURAC MP, IMPOSTONF IP, NOTAFISCAL NF, IMPOSTO IM,
                                        FORNECEDOR FO, CLIENTE CL, FILIAL FI, ENDEFORN EF, ENDECLIE EC, ENDEFILI EL
                                  WHERE MP.CDEMPRESA     = P_CDEMPRESA
                                    AND MP.CDIMPOSTO     = P_CDIMPOSTO
                                    AND MP.CDINSCESTA    = P_CDINSCESTA
                                    AND MP.DTINIPERIODO >= P_DTINICIAL
                                    AND MP.DTFIMPERIODO <= P_DTFINAL
                                    AND IP.NRSEQUMAPAPU  = MP.NRSEQUMAPAPU
                                    AND IP.CDFILIAL      = NF.CDFILIAL
                                    AND IP.NRLANCTONF    = NF.NRLANCTONF
                                    AND NF.IDENTRSAIDOP  = 'E'
                                    AND IP.CDIMPOSTO     = IM.CDIMPOSTO
                                    AND IM.CDIMPOSTONFE  = P_CDIMPOSTO
                                    AND NF.CDFORNECED    = EF.CDFORNECED(+)
                                    AND NF.CDCLIENTE     = EC.CDCLIENTE(+)
                                    AND NF.CDFILIEMIT    = EL.CDFILIAL(+)
                                    AND NF.CDFORNECED    = FO.CDFORNECED(+)
                                    AND NF.CDCLIENTE     = CL.CDCLIENTE(+)
                                    AND NF.CDFILIEMIT    = FI.CDFILIAL(+)
                                    AND EF.IDTPENDEFORN(+)= 'P'
                                    AND EC.IDTPENDECLIE(+)= 'P'
                                    AND EL.IDTPENDEFILI(+)= 'P'
                                    AND NF.CDMODDOCFISC <> '04'
                                    AND SUBSTR(CDFISCOPERNF,1,1) = '1'
                                    AND (IP.CDFISCOPERNF NOT IN ('1128','1153','1251','1253','1254','1255','1256','1257','1301','1302','1303','1304','1305','1306',
                                                                 '1351','1354','1355','1356','1406','1407','1414','1415','1503','1504','1505','1506','1551','1552',
                                                                 '1553','1554','1555','1556','1557','1601','1603','1605','1663','1664','1904','1905','1906','1907',
                                                                 '1908','1909','1911','1912','1913','1914','1915','1916','1920','1921','1922','1923','1933','1934','1949')
                                          OR (IP.CDFISCOPERNF = '1949' AND IP.VRIMPOSTONF > 0))
                                   GROUP BY NVL(NVL(EF.CDMUNICIPIO,EC.CDMUNICIPIO),EL.CDMUNICIPIO),
                                            NVL(NVL(EF.SGESTADO,EC.SGESTADO),EL.SGESTADO),NVL(NVL(EF.CDPAIS,EC.CDPAIS),EL.CDPAIS),
                                            NVL(NVL(FO.IDTPIJURFORN,CL.IDTPIJURCLIE),FI.IDTPIJURFILI), NF.CDMODDOCFISC, NF.CDSERIEENTR) A, MUNICIPIO MU
                                 WHERE MU.CDMUNICIPIO = A.MUNICIPIO
                                   AND MU.SGESTADO    = A.SGESTADO
                                   AND MU.CDPAIS      = A.CDPAIS
                                   AND MU.SGESTADO    = 'ES'
                                   AND (CASE WHEN ((MODELO = '1B') OR ((MODELO = '55') AND (SERIE BETWEEN '890' AND '899')) OR (IDTPIJURFORN = 'F'))
                                             THEN VRCONTABILNF ELSE 0 END) > 0
                                 GROUP BY  NVL(MU.CDMUNIEXPO,MU.CDMUNICIPIO)) LOOP

            /*TAG que indica cada registro (municpio) de detalhamento*/
            V_CONT := NVL(V_CONT,0)+1;
            INSERT INTO ARQMAGNETICO
               (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
            VALUES
               (LPAD(V_CONT,10,'0'),'<DETALHAMENTO>',P_NRSEQARQMAG);

               /*Cdigo do Muncipio*/
               V_CONT := NVL(V_CONT,0)+1;
               INSERT INTO ARQMAGNETICO
                  (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
               VALUES
                  (LPAD(V_CONT,10,'0'),'<CODG_MUNICIPIO>'||DETA_PROD.COD_MUNI||'</CODG_MUNICIPIO>',P_NRSEQARQMAG);

               /*Cdigo 4, que indica Produo Rural Prpria */
               V_CONT := NVL(V_CONT,0)+1;
               INSERT INTO ARQMAGNETICO
                  (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
               VALUES
                  (LPAD(V_CONT,10,'0'),'<CODG_DETALHAMENTO>4</CODG_DETALHAMENTO>',P_NRSEQARQMAG);

               /*Valor Contbil detalhado*/
               V_CONT := NVL(V_CONT,0)+1;
               INSERT INTO ARQMAGNETICO
                  (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
               VALUES
                  (LPAD(V_CONT,10,'0'),'<VALR_DETALHADO_1>'||DETA_PROD.VRCONTABIL||'</VALR_DETALHADO_1>',P_NRSEQARQMAG);

            /*Fechamento da TAG dos registros de detalhamento*/
            V_CONT := NVL(V_CONT,0)+1;
            INSERT INTO ARQMAGNETICO
               (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
            VALUES
               (LPAD(V_CONT,10,'0'),'</DETALHAMENTO>',P_NRSEQARQMAG);
         END LOOP;
      END IF;

      /* Caso haja valores de Aquisio de Pessoa Fsica ou No-Contribuinte de ICMS no Estado
      (NF-Avulsa - Modelo 1B ou NF-e Avulsa - Modelo 55 com Srie 890 a 899) deve ser gerado o detalhamento por municpio*/
      /*IF V_ENTR_PESSOAFISICA <> '0.00' THEN
         FOR DETA_AQZ IN(SELECT LTRIM(TO_CHAR(SUM(CASE WHEN ((MODELO = '1B') OR ((MODELO = '55') AND (SERIE BETWEEN '890' AND '899')) OR (IDTPIJURFORN = 'F'))
                                                       THEN VRCONTABILNF ELSE 0 END),'999999999999990.00')) AS VRCONTABIL,
                                 NVL(MU.CDMUNIEXPO,MU.CDMUNICIPIO) AS COD_MUNI
                            FROM(SELECT NVL(SUM(IP.VRCONTABILNF),0) AS VRCONTABILNF,
                                        NVL(NVL(EF.CDMUNICIPIO,EC.CDMUNICIPIO),EL.CDMUNICIPIO) AS MUNICIPIO,
                                        NVL(NVL(EF.SGESTADO,EC.SGESTADO),EL.SGESTADO) AS SGESTADO,
                                        NVL(NVL(EF.CDPAIS,EC.CDPAIS),EL.CDPAIS) AS CDPAIS,
                                        NVL(NVL(FO.IDTPIJURFORN,CL.IDTPIJURCLIE),FI.IDTPIJURFILI) AS IDTPIJURFORN,
                                        NF.CDMODDOCFISC AS MODELO, NF.CDSERIEENTR AS SERIE
                                   FROM MAPAAPURAC MP, IMPOSTONF IP, NOTAFISCAL NF, IMPOSTO IM,
                                        FORNECEDOR FO, CLIENTE CL, FILIAL FI, ENDEFORN EF, ENDECLIE EC, ENDEFILI EL
                                  WHERE MP.CDEMPRESA     = P_CDEMPRESA
                                    AND MP.CDIMPOSTO     = P_CDIMPOSTO
                                    AND MP.CDINSCESTA    = P_CDINSCESTA
                                    AND MP.DTINIPERIODO >= P_DTINICIAL
                                    AND MP.DTFIMPERIODO <= P_DTFINAL
                                    AND IP.NRSEQUMAPAPU  = MP.NRSEQUMAPAPU
                                    AND IP.CDFILIAL      = NF.CDFILIAL
                                    AND IP.NRLANCTONF    = NF.NRLANCTONF
                                    AND NF.IDENTRSAIDOP  = 'E'
                                    AND IP.CDIMPOSTO     = IM.CDIMPOSTO
                                    AND IM.CDIMPOSTONFE  = P_CDIMPOSTO
                                    AND NF.CDFORNECED    = EF.CDFORNECED(+)
                                    AND NF.CDCLIENTE     = EC.CDCLIENTE(+)
                                    AND NF.CDFILIEMIT    = EL.CDFILIAL(+)
                                    AND NF.CDFORNECED    = FO.CDFORNECED(+)
                                    AND NF.CDCLIENTE     = CL.CDCLIENTE(+)
                                    AND NF.CDFILIEMIT    = FI.CDFILIAL(+)
                                    AND EF.IDTPENDEFORN(+)= 'P'
                                    AND EC.IDTPENDECLIE(+)= 'P'
                                    AND EL.IDTPENDEFILI(+)= 'P'
                                    AND NF.CDMODDOCFISC <> '04'
                                    AND SUBSTR(CDFISCOPERNF,1,1) = '1'
                                    AND (IP.CDFISCOPERNF NOT IN ('1128','1153','1251','1253','1254','1255','1256','1257','1301','1302','1303','1304','1305','1306',
                                                                 '1351','1354','1355','1356','1406','1407','1414','1415','1503','1504','1505','1506','1551','1552',
                                                                 '1553','1554','1555','1556','1557','1601','1603','1605','1663','1664','1904','1905','1906','1907',
                                                                 '1908','1909','1911','1912','1913','1914','1915','1916','1920','1921','1922','1923','1933','1934','1949')
                                          OR (IP.CDFISCOPERNF = '1949' AND IP.VRIMPOSTONF > 0))
                                   GROUP BY NVL(NVL(EF.CDMUNICIPIO,EC.CDMUNICIPIO),EL.CDMUNICIPIO),
                                            NVL(NVL(EF.SGESTADO,EC.SGESTADO),EL.SGESTADO),NVL(NVL(EF.CDPAIS,EC.CDPAIS),EL.CDPAIS),
                                            NVL(NVL(FO.IDTPIJURFORN,CL.IDTPIJURCLIE),FI.IDTPIJURFILI), NF.CDMODDOCFISC, NF.CDSERIEENTR) A, MUNICIPIO MU
                                 WHERE MU.CDMUNICIPIO = A.MUNICIPIO
                                   AND MU.SGESTADO    = A.SGESTADO
                                   AND MU.CDPAIS      = A.CDPAIS
                                   AND MU.SGESTADO    = 'ES'
                                   AND (CASE WHEN ((MODELO = '1B') OR ((MODELO = '55') AND (SERIE BETWEEN '890' AND '899')) OR (IDTPIJURFORN = 'F'))
                                             THEN VRCONTABILNF ELSE 0 END) > 0
                                 GROUP BY  NVL(MU.CDMUNIEXPO,MU.CDMUNICIPIO)) LOOP

            /*TAG que indica cada registro (municpio) de detalhamento
            V_CONT := NVL(V_CONT,0)+1;
            INSERT INTO ARQMAGNETICO
               (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
            VALUES
               (LPAD(V_CONT,10,'0'),'<DETALHAMENTO>',P_NRSEQARQMAG);

               /*Cdigo do Muncipio*
               V_CONT := NVL(V_CONT,0)+1;
               INSERT INTO ARQMAGNETICO
                  (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
               VALUES
                  (LPAD(V_CONT,10,'0'),'<CODG_MUNICIPIO>'||DETA_AQZ.COD_MUNI||'</CODG_MUNICIPIO>',P_NRSEQARQMAG);

               /*Cdigo 7, que indica Aquisio de Pessoa Fsica
               V_CONT := NVL(V_CONT,0)+1;
               INSERT INTO ARQMAGNETICO
                  (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
               VALUES
                  (LPAD(V_CONT,10,'0'),'<CODG_DETALHAMENTO>7</CODG_DETALHAMENTO>',P_NRSEQARQMAG);

               /*Valor Contbil detalhado
               V_CONT := NVL(V_CONT,0)+1;
               INSERT INTO ARQMAGNETICO
                  (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
               VALUES
                  (LPAD(V_CONT,10,'0'),'<VALR_DETALHADO_1>'||DETA_AQZ.VRCONTABIL||'</VALR_DETALHADO_1>',P_NRSEQARQMAG);

            /*Fechamento da TAG dos registros de detalhamento
            V_CONT := NVL(V_CONT,0)+1;
            INSERT INTO ARQMAGNETICO
               (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
            VALUES
               (LPAD(V_CONT,10,'0'),'</DETALHAMENTO>',P_NRSEQARQMAG);
         END LOOP;
      END IF; */

      /*Caso haja valores de Outras Atividades (Operaes que compe o faturamento da empresa, conforme CFOP's de Venda)
      deve ser gerado o detalhamento por municpio*/
      IF V_OUTRAS_ATIVIDADES <> '0.00' THEN
         FOR DETA_OUTATIV IN (SELECT LTRIM(TO_CHAR(SUM(VRCONTABILNF),'999999999999990.00')) AS VRCONTABIL,
                                     NVL(DECODE(CFOP,'5',MU.CDMUNIEXPO, V_CDMUNIEXPO),MU.CDMUNICIPIO) AS COD_MUNI
                                FROM (SELECT SUBSTR(IP.CDFISCOPERNF,1,1) AS CFOP,
                                             NVL(SUM(IP.VRCONTABILNF),0) AS VRCONTABILNF,
                                             NVL(NVL(EF.CDMUNICIPIO,EC.CDMUNICIPIO),EL.CDMUNICIPIO) AS MUNICIPIO,
                                             NVL(NVL(EF.SGESTADO,EC.SGESTADO),EL.SGESTADO) AS SGESTADO,
                                             NVL(NVL(EF.CDPAIS,EC.CDPAIS),EL.CDPAIS) AS CDPAIS
                                        FROM MAPAAPURAC MP, IMPOSTONF IP, NOTAFISCAL NF, IMPOSTO IM, ENDEFORN EF, ENDECLIE EC, ENDEFILI EL, CFOPLIVROMAG CF
                                       WHERE MP.CDEMPRESA       = P_CDEMPRESA
                                         AND MP.CDIMPOSTO       = P_CDIMPOSTO
                                         AND MP.CDINSCESTA      = P_CDINSCESTA
                                         AND MP.DTINIPERIODO   >= P_DTINICIAL
                                         AND MP.DTFIMPERIODO   <= P_DTFINAL
                                         AND IP.NRSEQUMAPAPU    = MP.NRSEQUMAPAPU
                                         AND IP.CDFILIAL        = NF.CDFILIAL
                                         AND IP.NRLANCTONF      = NF.NRLANCTONF
                                         AND NF.IDENTRSAIDOP    = 'S'
                                         AND IP.CDIMPOSTO       = IM.CDIMPOSTO
                                         AND IM.CDIMPOSTONFE    = P_CDIMPOSTO
                                         AND NF.CDFORNECED      = EF.CDFORNECED(+)
                                         AND NF.CDCLIENTE       = EC.CDCLIENTE(+)
                                         AND NF.CDFILIRECE      = EL.CDFILIAL(+)
                                         AND CF.CDLIVROMAG      = P_CDLIVROMAG
                                         AND CF.CDLAYOUTLMAG    = '002'
                                         AND IP.CDFISCOPERNF     = CF.CDCFOPLMAG
                                         AND EF.IDTPENDEFORN(+) = 'P'
                                         AND EC.IDTPENDECLIE(+) = 'P'
                                         AND EL.IDTPENDEFILI(+) = 'P'
                                       GROUP BY SUBSTR(IP.CDFISCOPERNF,1,1), NVL(NVL(EF.CDMUNICIPIO,EC.CDMUNICIPIO),EL.CDMUNICIPIO),
                                             NVL(NVL(EF.SGESTADO,EC.SGESTADO),EL.SGESTADO), NVL(NVL(EF.CDPAIS,EC.CDPAIS),EL.CDPAIS))A, MUNICIPIO MU
                               WHERE MU.CDMUNICIPIO = A.MUNICIPIO
                                 AND MU.SGESTADO    = A.SGESTADO
                                 AND MU.CDPAIS      = A.CDPAIS
                               GROUP BY NVL(DECODE(CFOP,'5',MU.CDMUNIEXPO, V_CDMUNIEXPO),MU.CDMUNICIPIO)) LOOP

            /*TAG que indica cada registro (municpio) de detalhamento*/
            V_CONT := NVL(V_CONT,0)+1;
            INSERT INTO ARQMAGNETICO
               (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
            VALUES
               (LPAD(V_CONT,10,'0'),'<DETALHAMENTO>',P_NRSEQARQMAG);

               /*Cdigo do Muncipio*/
               V_CONT := NVL(V_CONT,0)+1;
               INSERT INTO ARQMAGNETICO
                  (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
               VALUES
                  (LPAD(V_CONT,10,'0'),'<CODG_MUNICIPIO>'||DETA_OUTATIV.COD_MUNI||'</CODG_MUNICIPIO>',P_NRSEQARQMAG);

               /*Cdigo 8, que indica Outras Atividades */
               V_CONT := NVL(V_CONT,0)+1;
               INSERT INTO ARQMAGNETICO
                  (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
               VALUES
                  (LPAD(V_CONT,10,'0'),'<CODG_DETALHAMENTO>8</CODG_DETALHAMENTO>',P_NRSEQARQMAG);

               /*Valor Contbil detalhado*/
               V_CONT := NVL(V_CONT,0)+1;
               INSERT INTO ARQMAGNETICO
                  (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
               VALUES
                  (LPAD(V_CONT,10,'0'),'<VALR_DETALHADO_1>'||DETA_OUTATIV.VRCONTABIL||'</VALR_DETALHADO_1>',P_NRSEQARQMAG);

            /*Fechamento da TAG dos registros de detalhamento*/
            V_CONT := NVL(V_CONT,0)+1;
            INSERT INTO ARQMAGNETICO
               (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
            VALUES
               (LPAD(V_CONT,10,'0'),'</DETALHAMENTO>',P_NRSEQARQMAG);
         END LOOP;
      END IF;

      V_CONT := NVL(V_CONT,0)+1;
      /*TAG que indica fim de gerao de Detalhamentos*/
      INSERT INTO ARQMAGNETICO
         (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
      VALUES
         (LPAD(V_CONT,10,'0'),'</DETALHAMENTOS>',P_NRSEQARQMAG);
   END IF;

   /*Fechamento da TAG de Declarao*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'</DECLARACAO>',P_NRSEQARQMAG);

   /*Fechamento da TAG de Abertura*/
   V_CONT := NVL(V_CONT,0)+1;
   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
      (LPAD(V_CONT,10,'0'),'</IMPORTAR_DOTS>',P_NRSEQARQMAG);
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('ARQUIVO_DOT','5.65.xxx'); END;
/
